@@ -2,10 +2,10 @@ from pytest import importorskip
 
 from miutil.imio import imread
 
+np = importorskip("numpy")
+
 
 def test_imread(tmp_path):
-    np = importorskip("numpy")
-
     x = np.random.randint(10, size=(9, 9))
     fname = tmp_path / "test_imread.npy"
     np.save(fname, x)
@@ -17,3 +17,13 @@ def test_imread(tmp_path):
 
     np.savez(fname, x, x)
     assert (imread(str(fname))["arr_0"] == x).all()
+
+
+def test_nii(tmp_path):
+    nii = importorskip("miutil.imio.nii")
+
+    x = np.arange(2 * 2 * 3).reshape(2, 2, 3)
+    fname = str(tmp_path / "test_nii.nii")
+    nii.array2nii(x, np.eye(4), fname, flip=(1, 1, 1))
+    nii.nii_gzip(fname)
+    assert (imread(fname + ".gz") == x).all()
